#include "Arduino.h"
#include "RDOT_ECD_2.0.h"

RDOT_ECD::RDOT_ECD(int counter_electrode, int segments[], int number_of_segments, int counter_voltage, int switching_time)
{

  _counter_electrode = counter_electrode;
  _switching_time = switching_time;
  _counter_voltage = counter_voltage;
  _number_of_segments = number_of_segments;

  for (int i = 0; i < _number_of_segments; i++)
  {
    _current_state[i] =  1;
    _segments[i] = segments[i];
    pinMode(_segments[i], INPUT);
  }    
  highImpMode();
}

void RDOT_ECD::highImpMode(){
  for (int i = 0; i < _number_of_segments; i++)
  {
    pinMode(_segments[i], INPUT);
  }
}

void RDOT_ECD::init()
{
  //Build up voltage at the reference electrode. 
  pinMode(_counter_electrode, OUTPUT);
  analogWrite(_counter_electrode, _counter_voltage);
  delay(3000);
  bool reset_1[_number_of_segments];
  bool reset_2[_number_of_segments];
  for (int i = 0; i < _number_of_segments; i++)
  {
    Serial.println(_segments[i]);
    _current_state[i] =  0;
    reset_1[i] = 1;
    reset_2[i] = 0;
  }    
  set(reset_1);
  set(reset_2);
}

void RDOT_ECD::set(bool next_state[])
{
  for (int i = 0; i < _number_of_segments; i++)
  {
    if(next_state[i] != _current_state[i])
    {
      pinMode(_segments[i], OUTPUT);
      digitalWrite(_segments[i], next_state[i]);
    }
    _current_state[i] = next_state[i];
  }
  delay(_switching_time);
  highImpMode();
}

// Functions for the single segment display
void RDOT_ECD::setNumber1x7(int number)
{
  if((number > 9) || (number < 0)){
    return;
  }
  bool state[7];
  for(int i = 0; i<7; i++){
    state[_1x7_seven_1[i]] = _seven_seg_states[number][i];
  }
  set(state);
}

// Functions for the double seven segment display
void RDOT_ECD::setNumber2x7(int number)
{
  if((number < -99) || (number>99)){
    return;
  }
  int digit_big = abs(number)/10;
  int digit_small = abs(number)%10;

  bool state[15];
  for(int i = 0; i<7; i++){
    state[_2x7_seven_1[i]] = _seven_seg_states[digit_big][i];
    state[_2x7_seven_2[i]] = _seven_seg_states[digit_small][i];
  }
  if(number<0){
    state[_2x7_sign] = 1;
  }
  else{
    state[_2x7_sign] = 0;
  }
  set(state);
}

// Functions for the bar display
void RDOT_ECD::setBar(int number)
{
  if((number > 8) || (number < 0)){
    return;
  }
  bool state[7] = {0,0,0,0,0,0,0};
  for(int i = 0; i<number; i++){
    state[_bar[i]] = 1;
  }
  set(state);
}


void RDOT_ECD::refresh()
{
  for (int i = 0; i < _number_of_segments; i++)
  {
    pinMode(_segments[i], OUTPUT);
    digitalWrite(_segments[i], _current_state[i]);
  }
  delay(_switching_time/4); 
  highImpMode(); 
}

